Client class

Constructors

Client(String Ip, double Latitude, double Longitude, String Isp, double IspRating, double Rating, int IspAvarageDownloadSpeed, int IspAvarageUploadSpeed, Coordinate geoCoordinate)
Client.fromXMLElement(XmlElement element)

Properties

geoCoordinate ↔ Coordinate
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Ip ↔ String
getter/setter pair
Isp ↔ String
getter/setter pair
IspAvarageDownloadSpeed ↔ int
getter/setter pair
IspAvarageUploadSpeed ↔ int
getter/setter pair
IspRating ↔ double
getter/setter pair
Latitude ↔ double
getter/setter pair
Longitude ↔ double
getter/setter pair
Rating ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited