Settings class

Constructors

Settings(Client client, Times times, Download download, Upload upload, ServerConfig serverConfig, List<Server> servers)
Settings.fromXMLElement(XmlElement element)

Properties

client ↔ Client
getter/setter pair
download ↔ Download
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverConfig ↔ ServerConfig
getter/setter pair
servers ↔ List<Server>
getter/setter pair
times ↔ Times
getter/setter pair
upload ↔ Upload
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited