Upload class

Constructors

Upload(int TestLength, int Ratio, int InitialTest, String MinTestSize, int Threads, String MaxChunkSize, String MaxChunkCount, int ThreadsPerUrl)
Upload.fromXMLElement(XmlElement element)

Properties

hashCode → int
The hash code for this object.
no setterinherited
InitialTest ↔ int
getter/setter pair
MaxChunkCount ↔ String
getter/setter pair
MaxChunkSize ↔ String
getter/setter pair
MinTestSize ↔ String
getter/setter pair
Ratio ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TestLength ↔ int
getter/setter pair
Threads ↔ int
getter/setter pair
ThreadsPerUrl ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited